Function notedealer::http_api::actor_id
source · [−]pub fn actor_id(base_url: &CanonicalServerUrl, username: &str) -> StringExpand description
Returns the id of an actor named username on this server.
pub fn actor_id(base_url: &CanonicalServerUrl, username: &str) -> StringReturns the id of an actor named username on this server.