Function notedealer::http_api::collection_page_id
source · [−]Expand description
Returns the ActivityPub id for a CollectionPage belonging to the given Collection, with the given page number.
Returns the ActivityPub id for a CollectionPage belonging to the given Collection, with the given page number.